@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "auto-save-visited-local-mode" "0.1.2"
+(define-package "auto-save-visited-local-mode" "20251021.1126"
   "Buffer-local auto-save for visited files."
   '((emacs "26.1"))
   :url "https://github.com/pierrelegall/auto-save-visited-local-mode"
